@@ -17,12 +17,12 @@ vars = [
         default=True),
     ]
 
+
 class PyllTemplate(templates.Template):
 
-    egg_plugins = ['Pyll']
+    egg_plugins = ['PasteScript', 'Pyll']
     summary = 'Template system for creating Pyll web framework applications.'
     required_templates = ['basic_package']
-    _template_dir = 'templates'
+    _template_dir =  'templates'
     use_cheetah = False
     vars=vars
-
